<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="be" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Пра праграму</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Катэгорыя:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Пачаць перадачу</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Прапусціць праверку хэшу</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Стварыць укладзеную папку</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Усе</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Без катэгорыі</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Дадаць катэгорыю...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Выдаліць катэгорыю</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Выдаліць нявыкарыстаныя катэгорыі</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Узнавіць торэнты</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Спыніць торэнты</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Выдаліць торэнты</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit category...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Выйсці з qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Адна спасылка на радок</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Агульнае абмежаванне хуткасці раздачы мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Агульнае абмежаванне хуткасці спампоўкі мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Альтэрнатыўнае абмежаванне хуткасці раздачы мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Альтэрнатыўнае абмежаванне хуткасці спампоўкі мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Максімум актыўных спамповак мусіць быць болей за -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Максімум актыўных раздач мусіць быць болей за -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Максімум актыўных торэнтаў мусіць быць болей за -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Максімальная колькасць злучэнняў мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максімальная колькасць злучэнняў на торэнт мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максімальная колькасць слотаў раздачы на торэнт мусіць быць болей за 0 або адключана.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Не выйшла захаваць настáўленні. Магчыма, qBittorrent недасяжны.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent на Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Невядомы</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Стасунак раздачы мусіць быць паміж 0 і 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Абмежаванне часу раздачы мусіць быць ад 0 да 525600 хвілін.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Порт для ўваходных злучэнняў мусіць быць паміж 1 і 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Порт для вэб-інтэрфейсу мусіць быць паміж 1 і 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Немагчыма ўвайсці. Выглядае, што qBittorrent недасяжны.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Нядзейсныя імя карыстальніка ці пароль.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Імя карыстальніка</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Логін</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Першапачатковыя аўтары</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ужыць</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Дадаць</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Раздаваць торэнты</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Захоўваць файлы сюды:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Кукі:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Пазначце папку тут</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Дадатковая інфармацыя</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Інфармацыя пра сертыфікаты</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Перамясціць</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Абмежаванне хуткасці раздачы</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Абмежаванне хуткасці спампавання</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Перайменаваць торэнт</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Іншае...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Панядзелак</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Аўторак</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Серада</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Чацвер</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Пятніца</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Субота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Нядзеля</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Выйсці</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Спампоўваць торэнты па іх адрасах або magnet-спасылках</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Зацягнуць лакальны торэнт</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Выдаліць вылучаныя торэнты са спісу перадач?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Захаваць</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Кліент qBittorrent недасяжны</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Free space: %1</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Кіраванне</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Сэрвіс</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Даведка</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Выгляд</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Настáўленні...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Узнавціь</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Найнізкі пр-тэт</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Найвысокі пр-тэт</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Зменшыць пр-тэт</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Павялічыць пр-тэт</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Верхняя панэль</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Панэль статуса</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Хуткасць у загалоўку</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Ахвяраваць!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Узнавіць усё</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статыстыка</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Пра qBittorrent</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Спыніць</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Выдаліць</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Спыніць усё</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Дадаць торэнт-файл...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Дакументацыя</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Дадаць спасылку на торэнт...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Не</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Агульнае абмежаванне хуткасці раздачы</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Агульнае абмежаванне хуткасці спампавання</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[Сц: %1, Разд: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Спампоўкі</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Злучэнне</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Хуткасць</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Веб-інтэрфейс</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Мова</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Мова інтерфейса:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Апавяшчэнне па электроннай пошце пасля завяршэння спампавання</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Запусціць знешнюю праграму па сканчэнні спампавання торэнта</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Фільтрацыя па IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Запланаваць выкарыстанне альтэрнатыўных абмежаванняў хуткасці</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Чарговасць торэнтаў</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Раздаваць торэнты пакуль іхні час раздачы не дасягне</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Аўтаматычна дадаваць гэтыя трэкеры да новых спамповак:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Веб-інтэрфейс (Аддаленае кіраванне)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-адрас:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Домены сервера:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Выкарыстоўваць HTTPS замест HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Мінаваць аўтэнтыфікацыю кліентаў для localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Мінаваць аўтэнтыфікацыю кліентаў для дазволеных падсетак</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Абнаўляць мой дынамічны DNS</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Захоўваць незавершаныя торэнты ў:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Капіяваць .torrent файлы ў:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Капіяваць .torrent файлы скончаных спамповак ў:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Папярэдне рэзерваваць месца для ўсіх файлаў</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Далучаць пашыренне .!qB да незавершаных файлаў</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Аўтаматычна дадаваць торэнты з:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-сервер:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Гэты сервер патрабуе бяспечнага злучэння (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аўтэнтыфікацыя</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Імя карыстальніка:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Ключаны пратакол:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP і μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Праслухоўваемы порт</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Порт для ўваходных злучэнняў:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Выкарыстоўваць UPnP / NAT-PMP майго маршрутызатара</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Выкарыстоўваць выпадковы порт пры запуску</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Абмежаванні злучэнняў</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Максімальная колькасцьзлучэнняў на торэнт:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Максімальная колькасць злучэнняў:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Максімальная колькасць слотаў аддачы на торэнт:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Максімальная колькасць слотаў раздач:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Проксі-сервер</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тып:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Няма)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>Сервер SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Выкарыстоўваць проксі для злучэння з пірамі</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Адключыць злученні непадтрымоўваныя проксі-серверам</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Выкарыстоўваць проксі толькі для торэнтаў</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Шлях да фільтраў (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Адрасы IP, забароненыя ўручную…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Прымяніць да трэкераў</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Глабальныя абмежаванні хуткасці</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Аддача:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Спампаванне:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Іншыя абмежаванні хуткасці</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>З:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Да:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Калі:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Кожны дзень</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Будні</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Выхадныя</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Налады абмежавання хуткасці</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Прымяніць абмежаванне хуткасці да службовага трафіку</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Прымяніць абмежаванне хуткасці да пратаколу µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Канфідэнцыяльнасць</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Уключыць DHT (дэцэнтралізаваную сетку), каб знайсці больш піраў</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Уключыць абмен пірамі (PeX), каб знайсці больш піраў</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Уключыць выяўленне лакальных піраў, каб знайсці больш піраў</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Рэжым шыфравання:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Аддаваць перавагу шыфраванню</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Патрабаваць шыфраванне</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Адключыць шыфраванне</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Уключыць ананімны рэжым</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Максімальная колькасць актыўных спамповак:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Максімальная колькасць актыўных раздач:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Максімальная колькасць актыўных торэнтаў:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Не ўлічваць колькасць павольных торэнтаў ў гэтых абмежаваннях</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Абмежаванне каэфіціента раздачы</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Раздаваць торэнты пакуль іхні каэфіціент раздачы не дасягне</translation>
    </message>
    <message>
        <source>then</source>
        <translation>затым</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Спыніць</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Выдаліць іх</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Выкарыстоўваць UPnP / NAT-PMP для перанакіравання порта ад майго маршрутызатара</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Сертыфікат:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Ключ:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Рэгістрацыя</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Даменнае імя:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Падтрымліваемыя параметры (з улікам рэгістру)</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Імя торэнта</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Катэгорыя</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Папка змесціва (тая ж, што і карэнная папка для шматфайлавых торэнтаў)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>% R: Карэнная папка (галоўны шлях для падкаталага торэнта)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Шлях захавання</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Колькасць файлаў</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Памер торэнта (байты)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Бягучы трэкер</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Хэш-сума</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Падказка: уключыце параметр у двукоссі каб пазбегнуць абразання на прабелах (напр. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Імя карыстальніка вэб-інтэрфейсу павінна быць не меншым за 3 знакі.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Пароль карыстальніка вэб-інтэрфейсу павінны быць не меньшым за 6 знакаў.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Сцяжкі</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Злучэнне</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Кліент</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Рух</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Хуткасць спампавання</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Хуткасць раздачы</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Сцягнута</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Раздадзена</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Рэлевантнасць</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Краіна</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Звычайны</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Высокі</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Максімальны</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Агульныя звесткі</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Трэкеры</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Піры</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-крыніцы</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Змесціва</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Сцягнута:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Перадача</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Час актыўнасці:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Часу засталося:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Раздадзена:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Сіды:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Хуткасць спампавання:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Хуткасць раздачы:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Піры:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Абмежаванне спампавання:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Абмежаванне раздачы:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Згублена:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Злучэнні:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інфармацыя</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Каментар:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Стасунак раздачы:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Пераабвяшчэнне праз:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Апошняя поўная прысутнасць:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Поўны памер:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Кавалкі:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Створаны ў:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Дададзены:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Скончаны:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Створаны:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Хэш торэнта:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Шлях захавання:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ніколі</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (з іх ёсць %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 гэтая сесія)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (макс. %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (усяго %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (сяр. %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Папка што наглядаецца</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Перавызначыць месца захавання</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Папка што наглядаецца</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Месца захавання па змаўчанні</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>КіБ/с</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Статыстыка</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Статыстыка карыстальніка</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Статыстыка кэшу</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Трапленняў у кэш чытання:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Сярэдні час прастою ў чарзе:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Статыстыка прадукцыйнасці</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Аперацый уводу/вываду ў чарзе:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Перагрузка кэшу запісу:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Перагрузка кэшу чытання:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Агульны памер чаргі:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 вузлоў</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Усе (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Спампоўваюцца (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Раздаюцца (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Скончаныя (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Узноўленыя (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Спыненыя (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Актыўныя (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Неактыўныя (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>З памылкамі (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Усе (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Спампоўваюцца (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Раздаюцца (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Скончаныя (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Спыненыя (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Узноўленыя (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Актыўныя (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Неактыўныя (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>З памылкамі (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Памер</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Рух</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Прыярытэт спампоўкі</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Засталося</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Даступнасць</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Памер</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Рух</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Сіды</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Піры</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Хуткасць сцягв.</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Хуткасць разд.</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Стасунак</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Часу засталося</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Катэгорыя</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Тэгі</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Дададзены</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Скончаны</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Трэкер</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Абмеж. сцягв.</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Абмеж. разд.</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Сцягнута</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Раздадзена</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Сцягнута за сеанс</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Раздадзена за сеанс</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Засталося</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Час актыўнасці</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Шлях захавання</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Выканана</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Абмежаванне стасунку</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Апошняя поўная прысутнасць</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Апошняя актыўнасць</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Поўны памер</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Спасылка</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Піры</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Паведамленне</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Акенца дадання трэкера</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Спіс трэкераў для дадання (па аднаму на радок):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 таму</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Катэгорыі</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Абмежаванне хуткасці спампавання торэнта</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Абмежаванне хуткасці раздачы торэнта</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Пераназваць</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Узнавіць</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Узнавіць прымусова</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Спыніць</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Выдаліць</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Абмежаваць стасунак раздачы...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Абмежаваць хуткасць раздачы...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Абмежаваць хуткасць спампавання...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Угору</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Долу</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>У самы верх</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>У самы ніз</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Перанесці змесціва...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Капіяваць назву</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Капіяваць хэш</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Спампоўваць з першай і апошняй часткі</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Аўтаматычнае кіраванне</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Катэгорыя</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Новая...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Скінуць</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Прыярытэт</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Праверыць прымусова</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Капіяваць Magnet-спасылку</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Рэжым супер-раздачы</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Пераназваць...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Спампоўваць паслядоўна</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Абмежаванне стасунку раздача/спампоўка торэнта</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Выкарыстоўваць глабальнае абмежаванне раздачы</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Прыбраць абмежаванне раздачы</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Задаць абмежаванне раздачы</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>стасунак</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>хвіліны</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Прасунуты BitTorrent-клиент, напісаны на C++. Заснаваны на Qt toolkit і libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Хатняя старонка:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Форум:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Баг-трэкер:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Пацверджанне выдалення</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Таксама выдаліць файлы з дыску</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Сцягнуць торэнты па спасылкам</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Сцягнуць</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>Б</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>КіБ</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>МіБ</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>ГіБ</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>ТіБ</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>ПіБ</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>ЭіБ</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/с</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1г %2хв</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1дз %2г</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Невядомы</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1хв</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1хв</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Go to description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>